@@ -24,10 +24,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         24,
         21,
         16,
-        27,
-        33,
+        28,
+        34,
         38,
-        18,
+        19,
         34,
         24,
         20,
@@ -45,18 +45,18 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         29,
         43,
         36,
-        30,
-        23,
-        23,
-        57,
-        38,
+        32,
+        27,
+        25,
+        59,
+        39,
         34,
         34,
         28,
         34,
         31,
         22,
-        33,
+        36,
         26,
     ],
     Book.EXODUS: [
@@ -87,7 +87,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         40,
         37,
         21,
-        43,
+        44,
         46,
         38,
         18,
@@ -106,7 +106,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         16,
         17,
         35,
-        19,
+        26,
         30,
         38,
         36,
@@ -137,20 +137,20 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         49,
         31,
         27,
-        89,
+        92,
         26,
         23,
         36,
         35,
         16,
-        33,
+        34,
         45,
         41,
         50,
         13,
         32,
         22,
-        29,
+        30,
         35,
         41,
         30,
@@ -160,7 +160,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         23,
         31,
         40,
-        16,
+        17,
         54,
         42,
         56,
@@ -169,7 +169,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         13,
     ],
     Book.DEUTERONOMY: [
-        46,
+        48,
         37,
         29,
         49,
@@ -194,10 +194,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         25,
         22,
         19,
-        19,
-        26,
+        20,
+        27,
         68,
-        29,
+        30,
         20,
         30,
         52,
@@ -206,10 +206,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
     ],
     Book.JOSHUA: [
         18,
-        24,
+        26,
         17,
-        24,
-        15,
+        25,
+        16,
         27,
         26,
         35,
@@ -222,7 +222,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         63,
         10,
         18,
-        28,
+        29,
         51,
         9,
         45,
@@ -232,11 +232,11 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
     ],
     Book.JUDGES: [
         36,
-        23,
+        29,
         31,
         24,
-        31,
-        40,
+        32,
+        41,
         25,
         35,
         57,
@@ -253,12 +253,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         48,
         25,
     ],
-    Book.RUTH: [
-        22,
-        23,
-        18,
-        22,
-    ],
+    Book.RUTH: [22, 23, 18, 22],
     Book.SAMUEL_1: [
         28,
         36,
@@ -279,11 +274,11 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         58,
         30,
         24,
-        42,
+        43,
         15,
         23,
         29,
-        22,
+        23,
         44,
         25,
         12,
@@ -297,7 +292,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         32,
         39,
         12,
-        25,
+        26,
         23,
         29,
         18,
@@ -324,7 +319,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         28,
         34,
         18,
-        38,
+        40,
         51,
         66,
         28,
@@ -340,7 +335,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         21,
         43,
         29,
-        53,
+        54,
     ],
     Book.KINGS_2: [
         18,
@@ -353,11 +348,11 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         29,
         37,
         36,
-        21,
+        22,
         21,
         25,
         29,
-        38,
+        39,
         20,
         41,
         37,
@@ -381,7 +376,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         44,
         14,
         47,
-        40,
+        41,
         14,
         17,
         29,
@@ -390,7 +385,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         17,
         19,
         8,
-        30,
+        31,
         19,
         32,
         31,
@@ -404,7 +399,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         17,
         18,
         17,
-        22,
+        23,
         14,
         42,
         22,
@@ -430,53 +425,18 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         9,
         27,
         36,
-        27,
+        28,
         21,
         33,
         25,
         33,
         27,
         23,
+        1,
     ],
-    Book.EZRA: [
-        11,
-        70,
-        13,
-        24,
-        17,
-        22,
-        28,
-        36,
-        15,
-        44,
-    ],
-    Book.NEHEMIAH: [
-        11,
-        20,
-        32,
-        23,
-        19,
-        19,
-        73,
-        18,
-        38,
-        39,
-        36,
-        47,
-        31,
-    ],
-    Book.ESTHER: [
-        22,
-        23,
-        15,
-        17,
-        14,
-        14,
-        10,
-        17,
-        32,
-        3,
-    ],
+    Book.EZRA: [11, 70, 13, 24, 17, 22, 28, 36, 15, 44],
+    Book.NEHEMIAH: [11, 20, 32, 23, 19, 19, 73, 18, 38, 39, 36, 47, 31],
+    Book.ESTHER: [22, 23, 15, 17, 15, 14, 10, 17, 32, 13, 12, 6, 18, 19, 19, 24],
     Book.JOB: [
         22,
         13,
@@ -493,7 +453,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         28,
         22,
         35,
-        22,
+        23,
         16,
         21,
         29,
@@ -516,162 +476,164 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         33,
         24,
         41,
-        30,
-        24,
+        38,
+        28,
         34,
         17,
     ],
     Book.PSALMS: [
         6,
-        12,
-        8,
-        8,
-        12,
-        10,
-        17,
-        9,
-        20,
-        18,
-        7,
-        8,
-        6,
-        7,
-        5,
-        11,
-        15,
-        50,
-        14,
-        9,
         13,
-        31,
-        6,
+        9,
+        10,
+        13,
+        11,
+        18,
+        10,
+        39,
+        18,
+        32,
+        9,
+        7,
+        7,
+        10,
+        15,
+        51,
+        51,
+        15,
+        14,
+        32,
+        32,
         10,
         22,
-        12,
+        22,
+        14,
         14,
-        9,
-        11,
-        12,
-        24,
         11,
+        13,
+        25,
+        25,
         22,
-        22,
+        23,
         28,
-        12,
+        29,
         40,
-        22,
-        13,
-        17,
-        13,
-        11,
-        5,
+        41,
+        23,
+        18,
+        18,
+        14,
+        12,
         26,
-        17,
+        27,
+        18,
+        12,
+        15,
+        21,
+        23,
+        25,
+        21,
         11,
         9,
+        24,
+        26,
+        14,
+        12,
+        18,
+        18,
+        14,
+        13,
+        13,
+        12,
         14,
         20,
-        23,
-        19,
-        9,
-        6,
-        7,
-        23,
-        13,
-        11,
-        11,
-        17,
-        12,
-        8,
-        12,
-        11,
-        10,
-        13,
-        20,
-        7,
-        35,
+        21,
         36,
-        5,
+        37,
+        37,
+        24,
         24,
-        20,
         28,
-        23,
-        10,
-        12,
-        20,
+        28,
+        24,
+        13,
+        21,
         72,
-        13,
+        72,
+        20,
+        20,
+        17,
         19,
-        16,
-        8,
-        18,
-        12,
-        13,
+        19,
+        14,
+        17,
+        17,
+        19,
+        53,
+        53,
         17,
-        7,
-        18,
-        52,
         17,
         16,
-        15,
-        5,
         23,
-        11,
+        23,
+        13,
         13,
         12,
         9,
         9,
-        5,
         8,
-        28,
-        22,
+        29,
+        29,
         35,
         45,
         48,
-        43,
-        13,
+        48,
+        44,
+        31,
         31,
-        7,
         10,
         10,
-        9,
-        8,
+        10,
+        26,
+        26,
         18,
         19,
-        2,
         29,
         176,
+        176,
+        176,
+        9,
+        9,
+        9,
+        8,
+        8,
+        6,
         7,
         8,
-        9,
-        4,
-        8,
-        5,
-        6,
-        5,
-        6,
         8,
         8,
-        3,
         18,
-        3,
-        3,
+        18,
+        18,
         21,
         26,
-        9,
-        8,
+        26,
+        27,
         24,
-        13,
-        10,
-        7,
+        24,
+        24,
+        14,
         12,
         15,
         21,
-        10,
+        21,
+        21,
+        20,
+        14,
         20,
         14,
         9,
-        6,
+        5,
     ],
     Book.PROVERBS: [
         33,
@@ -706,30 +668,8 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         33,
         31,
     ],
-    Book.ECCLESIASTES: [
-        18,
-        26,
-        22,
-        16,
-        20,
-        12,
-        29,
-        17,
-        18,
-        20,
-        10,
-        14,
-    ],
-    Book.SONG_OF_SONGS: [
-        17,
-        17,
-        11,
-        16,
-        16,
-        13,
-        13,
-        14,
-    ],
+    Book.ECCLESIASTES: [18, 26, 22, 17, 20, 12, 30, 17, 18, 20, 10, 14],
+    Book.SONG_OF_SONGS: [17, 17, 11, 16, 17, 13, 13, 14],
     Book.ISAIAH: [
         31,
         22,
@@ -752,7 +692,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         25,
         6,
         17,
-        25,
+        26,
         18,
         23,
         12,
@@ -775,7 +715,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         25,
         28,
         28,
-        25,
+        26,
         13,
         15,
         22,
@@ -796,6 +736,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         19,
         12,
         25,
+        25,
         24,
     ],
     Book.JEREMIAH: [
@@ -819,7 +760,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         23,
         15,
         18,
-        14,
+        15,
         30,
         40,
         10,
@@ -829,7 +770,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         17,
         32,
         24,
-        40,
+        42,
         44,
         26,
         22,
@@ -852,13 +793,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         64,
         34,
     ],
-    Book.LAMENTATIONS: [
-        22,
-        22,
-        66,
-        22,
-        22,
-    ],
+    Book.LAMENTATIONS: [22, 22, 66, 22, 22],
     Book.EZEKIEL: [
         28,
         10,
@@ -902,118 +837,26 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         49,
         26,
         20,
-        27,
+        28,
         31,
         25,
         24,
         23,
         35,
     ],
-    Book.DANIEL: [
-        21,
-        49,
-        30,
-        37,
-        31,
-        28,
-        28,
-        27,
-        27,
-        21,
-        45,
-        13,
-    ],
-    Book.HOSEA: [
-        11,
-        23,
-        5,
-        19,
-        15,
-        11,
-        16,
-        14,
-        17,
-        15,
-        12,
-        14,
-        16,
-        9,
-    ],
-    Book.JOEL: [
-        20,
-        32,
-        21,
-    ],
-    Book.AMOS: [
-        15,
-        16,
-        15,
-        13,
-        27,
-        14,
-        17,
-        14,
-        15,
-    ],
-    Book.OBADIAH: [
-        21,
-    ],
-    Book.JONAH: [
-        17,
-        10,
-        10,
-        11,
-    ],
-    Book.MICAH: [
-        16,
-        13,
-        12,
-        13,
-        15,
-        16,
-        20,
-    ],
-    Book.NAHUM: [
-        15,
-        13,
-        19,
-    ],
-    Book.HABAKKUK: [
-        17,
-        20,
-        19,
-    ],
-    Book.ZEPHANIAH: [
-        18,
-        15,
-        20,
-    ],
-    Book.HAGGAI: [
-        15,
-        23,
-    ],
-    Book.ZECHARIAH: [
-        21,
-        13,
-        10,
-        14,
-        11,
-        15,
-        14,
-        23,
-        17,
-        12,
-        17,
-        14,
-        9,
-        21,
-    ],
-    Book.MALACHI: [
-        14,
-        17,
-        18,
-        6,
-    ],
+    Book.DANIEL: [21, 49, 100, 37, 31, 29, 28, 27, 27, 21, 45, 13, 65, 42],
+    Book.HOSEA: [11, 24, 5, 19, 15, 11, 16, 14, 17, 15, 12, 15, 16, 10],
+    Book.JOEL: [20, 32, 26],
+    Book.AMOS: [15, 16, 15, 13, 27, 15, 17, 14, 15],
+    Book.OBADIAH: [21],
+    Book.JONAH: [17, 11, 10, 11],
+    Book.MICAH: [16, 13, 12, 14, 15, 18, 20],
+    Book.NAHUM: [15, 14, 19],
+    Book.HABAKKUK: [17, 20, 19],
+    Book.ZEPHANIAH: [18, 15, 20],
+    Book.HAGGAI: [15, 24],
+    Book.ZECHARIAH: [21, 17, 10, 14, 11, 15, 14, 23, 17, 12, 17, 14, 9, 21],
+    Book.MALACHI: [14, 17, 18, 6],
     Book.MATTHEW: [
         25,
         23,
@@ -1044,27 +887,10 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         66,
         20,
     ],
-    Book.MARK: [
-        45,
-        28,
-        35,
-        41,
-        43,
-        56,
-        37,
-        38,
-        50,
-        52,
-        33,
-        44,
-        37,
-        72,
-        47,
-        20,
-    ],
+    Book.MARK: [45, 28, 35, 41, 43, 56, 37, 39, 50, 52, 33, 44, 37, 72, 47, 20],
     Book.LUKE: [
         80,
-        52,
+        53,
         38,
         44,
         39,
@@ -1072,7 +898,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         50,
         56,
         62,
-        42,
+        43,
         54,
         59,
         35,
@@ -1089,12 +915,12 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         53,
     ],
     Book.JOHN: [
-        51,
+        52,
         25,
         36,
         54,
         47,
-        71,
+        72,
         53,
         59,
         41,
@@ -1141,24 +967,7 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         44,
         31,
     ],
-    Book.ROMANS: [
-        32,
-        29,
-        31,
-        25,
-        21,
-        23,
-        25,
-        39,
-        33,
-        21,
-        36,
-        21,
-        14,
-        23,
-        33,
-        27,
-    ],
+    Book.ROMANS: [32, 29, 31, 25, 21, 23, 25, 39, 33, 21, 36, 21, 14, 26, 33, 27],
     Book.CORINTHIANS_1: [
         31,
         16,
@@ -1177,133 +986,25 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         58,
         24,
     ],
-    Book.CORINTHIANS_2: [
-        24,
-        17,
-        18,
-        18,
-        21,
-        18,
-        16,
-        24,
-        15,
-        18,
-        33,
-        21,
-        14,
-    ],
-    Book.GALATIANS: [
-        24,
-        21,
-        29,
-        31,
-        26,
-        18,
-    ],
-    Book.EPHESIANS: [
-        23,
-        22,
-        21,
-        32,
-        33,
-        24,
-    ],
-    Book.PHILIPPIANS: [
-        30,
-        30,
-        21,
-        23,
-    ],
-    Book.COLOSSIANS: [
-        29,
-        23,
-        25,
-        18,
-    ],
-    Book.THESSALONIANS_1: [
-        10,
-        20,
-        13,
-        18,
-        28,
-    ],
-    Book.THESSALONIANS_2: [
-        12,
-        17,
-        18,
-    ],
-    Book.TIMOTHY_1: [
-        20,
-        15,
-        16,
-        16,
-        25,
-        21,
-    ],
-    Book.TIMOTHY_2: [
-        18,
-        26,
-        17,
-        22,
-    ],
-    Book.TITUS: [
-        16,
-        15,
-        15,
-    ],
-    Book.PHILEMON: [
-        25,
-    ],
-    Book.HEBREWS: [
-        14,
-        18,
-        19,
-        16,
-        14,
-        20,
-        28,
-        13,
-        28,
-        39,
-        40,
-        29,
-        25,
-    ],
-    Book.JAMES: [
-        27,
-        26,
-        18,
-        17,
-        20,
-    ],
-    Book.PETER_1: [
-        25,
-        25,
-        22,
-        19,
-        14,
-    ],
-    Book.PETER_2: [
-        21,
-        22,
-        18,
-    ],
-    Book.JOHN_1: [
-        10,
-        29,
-        24,
-        21,
-        21,
-    ],
-    Book.JOHN_2: [
-        13,
-    ],
-    Book.JOHN_3: [
-        14,
-    ],
-    Book.JUDE: [
-        25,
-    ],
+    Book.CORINTHIANS_2: [24, 17, 18, 18, 21, 18, 16, 24, 15, 18, 33, 21, 14],
+    Book.GALATIANS: [24, 21, 29, 31, 26, 18],
+    Book.EPHESIANS: [23, 22, 21, 32, 33, 24],
+    Book.PHILIPPIANS: [30, 30, 21, 23],
+    Book.COLOSSIANS: [29, 23, 25, 18],
+    Book.THESSALONIANS_1: [10, 20, 13, 18, 28],
+    Book.THESSALONIANS_2: [12, 17, 18],
+    Book.TIMOTHY_1: [20, 15, 16, 16, 25, 21],
+    Book.TIMOTHY_2: [18, 26, 17, 22],
+    Book.TITUS: [16, 15, 15],
+    Book.PHILEMON: [25],
+    Book.HEBREWS: [14, 18, 19, 16, 14, 20, 28, 13, 28, 39, 40, 29, 25],
+    Book.JAMES: [27, 26, 18, 17, 20],
+    Book.PETER_1: [25, 25, 22, 19, 14],
+    Book.PETER_2: [21, 22, 18],
+    Book.JOHN_1: [10, 29, 24, 21, 21],
+    Book.JOHN_2: [13],
+    Book.JOHN_3: [15],
+    Book.JUDE: [25],
     Book.REVELATION: [
         20,
         29,
@@ -1316,8 +1017,8 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         21,
         11,
         19,
-        17,
         18,
+        19,
         20,
         8,
         21,
@@ -1329,15 +1030,25 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         21,
     ],
     Book.ESDRAS_1: [
-        55,
-        25,
-        23,
+        58,
+        31,
+        24,
         63,
-        70,
-        33,
-        15,
-        92,
-        55,
+        73,
+        34,
+        30,
+        97,
+        56,
+        21,
+        27,
+        27,
+        19,
+        31,
+        19,
+        29,
+        20,
+        25,
+        20,
     ],
     Book.TOBIT: [
         22,
@@ -1356,114 +1067,81 @@ MAX_VERSE_NUMBER_BY_BOOK_AND_CHAPTER: dict[Book, list[int]] = {
         15,
     ],
     Book.WISDOM_OF_SOLOMON: [
-        16,
-        24,
-        19,
+        77,
+        38,
+        37,
         20,
-        23,
-        25,
-        30,
-        21,
-        18,
-        21,
-        26,
+        72,
         27,
+        32,
+        36,
         19,
+        23,
+        27,
+        27,
+        20,
         31,
         19,
         29,
-        21,
+        20,
         25,
-        22,
+        20,
     ],
     Book.ECCLESIASTICUS: [
-        30,
+        40,
+        23,
+        34,
+        36,
         18,
-        31,
-        31,
-        15,
-        37,
+        38,
+        40,
+        21,
+        25,
+        34,
         36,
         19,
-        18,
-        31,
-        34,
-        18,
-        26,
-        27,
-        20,
-        30,
         32,
-        33,
-        30,
-        31,
-        28,
         27,
-        27,
-        34,
-        26,
-        29,
-        30,
-        26,
-        28,
-        25,
-        31,
-        24,
-        33,
-        31,
-        26,
-        31,
-        31,
-        34,
-        35,
-        30,
         22,
-        25,
+        31,
         33,
-        23,
-        26,
-        20,
-        25,
-        25,
-        16,
-        29,
-        30,
-    ],
-    Book.MACCABEES_1: [
-        64,
-        70,
-        60,
-        61,
-        68,
-        63,
-        50,
-        32,
-        73,
-        89,
-        74,
-        53,
-        53,
-        49,
-        41,
-        24,
-    ],
-    Book.MACCABEES_2: [
+        33,
+        28,
+        33,
+        31,
+        33,
+        38,
+        47,
         36,
+        30,
+        33,
+        30,
+        35,
+        27,
+        42,
+        28,
+        33,
+        31,
+        26,
+        28,
+        34,
+        39,
+        41,
         32,
-        40,
-        50,
+        28,
+        25,
+        37,
         27,
         31,
-        42,
-        36,
-        29,
+        23,
+        31,
+        28,
+        19,
+        31,
         38,
-        38,
-        45,
-        26,
-        46,
-        39,
     ],
+    Book.MACCABEES_1: [67, 70, 60, 61, 68, 63, 50, 32, 73, 89, 74, 54, 54, 49, 41, 24],
+    Book.MACCABEES_2: [67, 70, 60, 61, 68, 63, 50, 36, 73, 89, 74, 54, 54, 49, 41, 24],
 }
 
 BOOK_PLACE = 1000000
